@@ -1,8 +1,8 @@
 package Strehler::Admin;
-$Strehler::Admin::VERSION = '1.6.6';
+$Strehler::Admin::VERSION = '1.6.7';
 use strict;
 use Cwd 'abs_path';
-use Dancer2 0.160000;
+use Dancer2 0.166000;
 use Dancer2::Plugin::DBIC;
 use Dancer2::Plugin::Ajax;
 use Dancer2::Serializer::JSON;
@@ -112,7 +112,14 @@ ajax '/image/src/:id' => sub
 
 any '/user/add' => sub
 {
-    send_error("Access denied", 403) && return if ( ! Strehler::Element::User->check_role(session->read('role')));
+    if ( ! Strehler::Element::User->check_role(session->read('role')))
+    {
+        Dancer2::Core::Error->new(
+             response => response(),
+             status   => 403,
+             message  => "Access denied",
+         )->throw;
+    }
     my $form = Strehler::Forms::form_user('add');
     my $params_hashref = params;
     $form->process($params_hashref);
@@ -135,7 +142,14 @@ any '/user/add' => sub
 };
 
 get '/user/edit/:id' => sub {
-    send_error("Access denied", 403) && return if ( ! Strehler::Element::User->check_role(session->read('role')));
+    if ( ! Strehler::Element::User->check_role(session->read('role')))
+    {
+        Dancer2::Core::Error->new(
+             response => response(),
+             status   => 403,
+             message  => "Access denied",
+        )->throw;
+    }
     my $id = params->{id};
     my $user = Strehler::Element::User->new($id);
     my $form_data = $user->get_form_data();
@@ -146,7 +160,14 @@ get '/user/edit/:id' => sub {
 
 post '/user/edit/:id' => sub
 {
-    send_error("Access denied", 403) && return if ( ! Strehler::Element::User->check_role(session->read('role')));
+    if ( ! Strehler::Element::User->check_role(session->read('role')))
+    {
+        Dancer2::Core::Error->new(
+             response => response(),
+             status   => 403,
+             message  => "Access denied",
+        )->throw;
+    }
     my $form = Strehler::Forms::form_user('edit');
     my $id = params->{id};
     my $params_hashref = params;
@@ -177,7 +198,14 @@ get '/user/password' => sub {
 };
 post '/user/password' => sub
 {
-    send_error("Wrong call", 500) && return if params->{user};
+    if( params->{user} )
+    {
+        Dancer2::Core::Error->new(
+             response => response(),
+             status   => 500,
+             message  => "Wrong call",
+        )->throw;
+    }
     my $user = Strehler::Element::User->get_from_username(session->read('user'));
     my $id = $user->get_attr('id');
     my $form = Strehler::Forms::form_user('password');
@@ -206,13 +234,27 @@ post '/user/password' => sub
 
 get '/category' => sub
 {
-    send_error("Access denied", 403) && return if ( ! Strehler::Meta::Category->check_role(session->read('role')));
+    if ( ! Strehler::Meta::Category->check_role(session->read('role')))
+    {
+      Dancer2::Core::Error->new(
+             response => response(),
+             status   => 403,
+             message  => "Access denied",
+        )->throw;
+    }
     redirect dancer_app->prefix . '/category/list';
 };
 
 any '/category/list' => sub
 {
-    send_error("Access denied", 403) && return if ( ! Strehler::Meta::Category->check_role(session->read('role')));
+    if ( ! Strehler::Meta::Category->check_role(session->read('role')))
+    {
+        Dancer2::Core::Error->new(
+             response => response(),
+             status   => 403,
+             message  => "Access denied",
+         )->throw
+    }
 
     #THE TABLE
     my @to_view = Strehler::Meta::Category->get_list();
@@ -233,7 +275,14 @@ any '/category/list' => sub
 
 any '/category/add' => sub
 {
-    send_error("Access denied", 403) && return if ( ! Strehler::Meta::Category->check_role(session->read('role')));
+    if ( ! Strehler::Meta::Category->check_role(session->read('role')))
+    {
+        Dancer2::Core::Error->new(
+             response => response(),
+             status   => 403,
+             message  => "Access denied",
+         )->throw
+    }
     my $form = Strehler::Forms::form_category();
     my $params_hashref = params;
     my @entities = Strehler::Helpers::get_categorized_entities();
@@ -247,7 +296,14 @@ any '/category/add' => sub
     template "admin/category", { form => $form->render() }
 };
 get '/category/edit/:id' => sub {
-    send_error("Access denied", 403) && return if ( ! Strehler::Meta::Category->check_role(session->read('role')));
+    if ( ! Strehler::Meta::Category->check_role(session->read('role')))
+    {
+        Dancer2::Core::Error->new(
+             response => response(),
+             status   => 403,
+             message  => "Access denied",
+         )->throw
+    }
     my $id = params->{id};
     my $category = Strehler::Meta::Category->new($id);
     my @entities = Strehler::Helpers::get_categorized_entities();
@@ -260,7 +316,14 @@ get '/category/edit/:id' => sub {
 };
 post '/category/edit/:id' => sub
 {
-    send_error("Access denied", 403) && return if ( ! Strehler::Meta::Category->check_role(session->read('role')));
+    if ( ! Strehler::Meta::Category->check_role(session->read('role')))
+    {
+        Dancer2::Core::Error->new(
+             response => response(),
+             status   => 403,
+             message  => "Access denied",
+         )->throw
+    }
     my $form = Strehler::Forms::form_category();
     my $id = params->{id};
     my $params_hashref = params;
@@ -277,7 +340,14 @@ post '/category/edit/:id' => sub
 
 get '/category/delete/:id' => sub
 {
-    send_error("Access denied", 403) && return if ( ! Strehler::Meta::Category->check_role(session->read('role')));
+    if ( ! Strehler::Meta::Category->check_role(session->read('role')))
+    {
+        Dancer2::Core::Error->new(
+             response => response(),
+             status   => 403,
+             message  => "Access denied",
+         )->throw
+    }
     my $id = params->{id};
     my $category = Strehler::Meta::Category->new($id);
     my %data = $category->get_basic_data();
@@ -285,7 +355,14 @@ get '/category/delete/:id' => sub
 };
 post '/category/delete/:id' => sub
 {
-    send_error("Access denied", 403) && return if ( ! Strehler::Meta::Category->check_role(session->read('role')));
+    if ( ! Strehler::Meta::Category->check_role(session->read('role')))
+    {
+        Dancer2::Core::Error->new(
+             response => response(),
+             status   => 403,
+             message  => "Access denied",
+         )->throw
+    }
     my $id = params->{id};
     my $category = Strehler::Meta::Category->new($id);
     my $code = $category->delete();
@@ -298,7 +375,15 @@ post '/category/delete/:id' => sub
 };
 post '/category/delete-tree/:id' => sub
 {
-    send_error("Access denied", 403) && return if ( ! Strehler::Meta::Category->check_role(session->read('role')));
+    if ( ! Strehler::Meta::Category->check_role(session->read('role')))
+    {
+        Dancer2::Core::Error->new(
+             response => response(),
+             status   => 403,
+             message  => "Access denied",
+         )->throw
+    }
+    
     my $id = params->{id};
     my $category = Strehler::Meta::Category->new($id);
     my @categories_to_delete = ( $category );
@@ -436,7 +521,15 @@ get '/:entity' => sub
     my $class = Strehler::Helpers::class_from_entity($entity);
     if($class)
     {
-        send_error("Access denied", 403) && return if ( ! $class->check_role(session->read('role')));
+        if ( ! $class->check_role(session->read('role')))
+        {
+            Dancer2::Core::Error->new(
+                response => response(),
+                status   => 403,
+                message  => "Access denied",
+            )->throw
+        }
+    
         redirect dancer_app->prefix . '/' . $entity . '/list';
     }
     else
@@ -454,7 +547,15 @@ any '/:entity/list' => sub
     {
         return pass;
     }
-    send_error("Access denied", 403) && return if ( ! $class->check_role(session->read('role')));
+    if ( ! $class->check_role(session->read('role')))
+    {
+        Dancer2::Core::Error->new(
+             response => response(),
+             status   => 403,
+             message  => "Access denied",
+         )->throw
+    }
+    
 
     #Parameters collection
     my $input_params;
@@ -524,7 +625,15 @@ get '/:entity/turnon/:id' => sub
     {
         return pass;
     }
-    send_error("Access denied", 403) && return if ( ! $class->check_role(session->read('role')));
+    if ( ! $class->check_role(session->read('role')))
+    {
+        Dancer2::Core::Error->new(
+             response => response(),
+             status   => 403,
+             message  => "Access denied",
+         )->throw
+    }
+    
     my $id = params->{id};
     my $obj = $class->new($id);
     my $code = $obj->publish();
@@ -544,7 +653,15 @@ get '/:entity/turnoff/:id' => sub
     {
         return pass;
     }
-    send_error("Access denied", 403) && return if ( ! $class->check_role(session->read('role')));
+    if ( ! $class->check_role(session->read('role')))
+    {
+        Dancer2::Core::Error->new(
+             response => response(),
+             status   => 403,
+             message  => "Access denied",
+         )->throw
+    }
+    
     my $id = params->{id};
     my $obj = $class->new($id);
     my $code = $obj->unpublish();
@@ -563,7 +680,15 @@ get '/:entity/delete/:id' => sub
     {
         return pass;
     }
-    send_error("Access denied", 403) && return if ( ! $class->check_role(session->read('role')));
+    if ( ! $class->check_role(session->read('role')))
+    {
+        Dancer2::Core::Error->new(
+             response => response(),
+             status   => 403,
+             message  => "Access denied",
+         )->throw
+    }
+    
     my $id = params->{id};
     my $obj = $class->new($id);
     my %el = $obj->get_basic_data();
@@ -577,7 +702,15 @@ post '/:entity/delete/:id' => sub
     {
         return pass;
     }
-    send_error("Access denied", 403) && return if ( ! $class->check_role(session->read('role')));
+    if ( ! $class->check_role(session->read('role')))
+    {
+        Dancer2::Core::Error->new(
+             response => response(),
+             status   => 403,
+             message  => "Access denied",
+         )->throw
+    }
+    
     my $id = params->{id};
     my $obj = $class->new($id);
     my $code = $obj->delete();
@@ -657,7 +790,15 @@ any '/:entity/add' => sub
         return template "admin/no_category", { message => $message, backlink => $return, createlink => $create };
     }
 
-    send_error("Access denied", 403) && return if ( ! $class->check_role(session->read('role')));
+    if ( ! $class->check_role(session->read('role')))
+    {
+        Dancer2::Core::Error->new(
+             response => response(),
+             status   => 403,
+             message  => "Access denied",
+         )->throw
+    }
+    
     my $form = Strehler::Forms::form_generic($class->form(), $class->multilang_form(), {languages => \@languages, default_language => config->{'Strehler'}->{'default_language'}, only_default_required => $class->only_default_required() } ); 
     my $params_hashref = params;
     $form = Strehler::Forms::tags_for_form($form, $params_hashref);
@@ -770,7 +911,15 @@ get '/:entity/edit/:id' => sub {
             session 'backlink' => undef;
         }
     }
-    send_error("Access denied", 403) && return if ( ! $class->check_role(session->read('role')));
+    if ( ! $class->check_role(session->read('role')))
+    {
+        Dancer2::Core::Error->new(
+             response => response(),
+             status   => 403,
+             message  => "Access denied",
+         )->throw
+    }
+    
     my $el = $class->new($id);
     my $form_data = $el->get_form_data();
     my $form = Strehler::Forms::form_generic($class->form(), $class->multilang_form(), {languages => \@languages, default_language => config->{'Strehler'}->{'default_language'}, only_default_required => $class->only_default_required() } ); 
@@ -793,7 +942,14 @@ post '/:entity/edit/:id' => sub
     {
         return pass;
     }
-    send_error("Access denied", 403) && return if ( ! $class->check_role(session->read('role')));
+    if ( ! $class->check_role(session->read('role')))
+    {
+        Dancer2::Core::Error->new(
+             response => response(),
+             status   => 403,
+             message  => "Access denied",
+         )->throw
+    }
     my $form = Strehler::Forms::form_generic($class->form(), $class->multilang_form(), {languages => \@languages, default_language => config->{'Strehler'}->{'default_language'}, only_default_required => $class->only_default_required() } ); 
     if(! $form)
     {
@@ -851,14 +1007,25 @@ post '/:entity/edit/:id' => sub
 get '/dashboard/:lang' => sub {
     if(! config->{'Strehler'}->{'dashboard_active'} || config->{'Strehler'}->{'dashboard_active'} == 0)
     {
-        return pass;
+        #return pass;
+        Dancer2::Core::Error->new(
+             response => response(),
+             status   => 404,
+             message  => "Not found",
+        )->throw
     }
     my %navbar;
     $navbar{'home'} = "active";
     my $language = params->{'lang'};
     if ( ! grep { $_ eq $language } @languages )
     {
-        return pass;
+        #return pass;
+        Dancer2::Core::Error->new(
+             response => response(),
+             status   => 404,
+             message  => "Not found",
+        )->throw
+
     }
 
     my $dashboard_data = config->{'Strehler'}->{'dashboard'};
